﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using static System.Windows.Forms.DataFormats;

namespace Airbus
{
    public partial class FormMapWithSetAirplane : Form
    {
        private AbstractMap _abstractMap;
        private MapWithSetAirplaneGeneric<DrawningObjectAirplane, AbstractMap> _mapAirplanesCollectionGeneric;
        /// <summary>
        /// Конструктор
        /// </summary>
        public FormMapWithSetAirplane()
        {
            InitializeComponent();
        }
        /// <summary>
        /// Выбор карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ComboBoxSelectorMap_SelectedIndexChanged(object sender,
       EventArgs e)
        {
            AbstractMap map = null;
            switch (comboBoxSelectorMap.Text)
            {
                case "Первая карта":
                    map = new SimpleMap();
                    break;
                case "Вторая карта":
                    map = new SecondMap();
                    break;
                case "Третья карта":
                    map = new ThirdMap();
                    break;
            }
            if (map != null)
            {
                _mapAirplanesCollectionGeneric = new
               MapWithSetAirplaneGeneric<DrawningObjectAirplane, AbstractMap>(
                pictureBox.Width, pictureBox.Height, map);
            }
            else
            {
                _mapAirplanesCollectionGeneric = null;
            }
        }
        /// <summary>
        /// Добавление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonAddAirplane_Click(object sender, EventArgs e)
        {
            if (_mapAirplanesCollectionGeneric == null)
            {
                return;
            }
            FormAirplane form = new();
            if (form.ShowDialog() == DialogResult.OK)
            {
                DrawningObjectAirplane airplane = new(form.SelectedAirplane);
                if (_mapAirplanesCollectionGeneric + airplane > -1)
                {
                    MessageBox.Show("Объект добавлен");
                    pictureBox.Image = _mapAirplanesCollectionGeneric.ShowSet();
                }
                else
                {
                    MessageBox.Show("Не удалось добавить объект");
                }
            }
        }
        /// <summary>
        /// Удаление объекта
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonRemoveAirplane_Click(object sender, EventArgs e)
        {
            if (string.IsNullOrEmpty(maskedTextBoxPosition.Text))
            {
                return;
            }
            if (MessageBox.Show("Удалить объект?", "Удаление",
           MessageBoxButtons.YesNo, MessageBoxIcon.Question) == DialogResult.No)
            {
                return;
            }
            int pos = Convert.ToInt32(maskedTextBoxPosition.Text);
            if (_mapAirplanesCollectionGeneric - pos != null )
            {
                MessageBox.Show("Объект удален");
                pictureBox.Image = _mapAirplanesCollectionGeneric.ShowSet();
            }
            else
            {
                MessageBox.Show("Не удалось удалить объект");
            }
        }
        /// <summary>
        /// Вывод набора
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonStorage_Click(object sender, EventArgs e)
        {
            if (_mapAirplanesCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapAirplanesCollectionGeneric.ShowSet();
        }
        /// <summary>
        /// Вывод карты
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void buttonShowOnMap_Click(object sender, EventArgs e)
        {
            if (_mapAirplanesCollectionGeneric == null)
            {
                return;
            }
            pictureBox.Image = _mapAirplanesCollectionGeneric.ShowOnMap();
            
        }
        /// <summary>
        /// Перемещение
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void ButtonMove_Click(object sender, EventArgs e)
        {
            if (_mapAirplanesCollectionGeneric == null)
            {
                return;
            }
            //получаем имя кнопки
            string name = ((Button)sender)?.Name ?? string.Empty;
            Direction dir = Direction.None;
            switch (name)
            {
                case "buttonUp":
                    dir = Direction.Up;
                    break;
                case "buttonDown":
                    dir = Direction.Down;
                    break;
                case "buttonLeft":
                    dir = Direction.Left;
                    break;
                case "buttonRight":
                    dir = Direction.Right;
                    break;
            }
            pictureBox.Image = _mapAirplanesCollectionGeneric.MoveObject(dir);
        }

    }
}
