﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace Airbus
{
    internal class SetAirplaneGeneric<T>
        where T : class
    {
        private readonly T[] _places;
        public int Count => _places.Length;
        public SetAirplaneGeneric(int count)
        {
            _places = new T[count];
        }
        
        /// <summary>
        /// Добавление объекта в набор на конкретную позицию
        /// </summary>
        /// <param name="car">Добавляемый автомобиль</param>
        /// <param name="position">Позиция</param>
        /// <returns></returns>
        private bool CanInsert(int position)
        {
            for (int i = position; i < _places.Length; i++)
                if (_places[i] == null) 
                    return true;
            return false;
        }

        public int Insert(T airplane)
        {
            return Insert(airplane, 0);
        }

        public int Insert(T airplane, int position)
        {
            if (position < 0 || position > _places.Length) return 0;
            if (_places[position] != null && CanInsert(position))
            {
                for (int i = _places.Length - 1; i > position; --i)
                {
                    if (_places[i] == null)
                    {
                        _places[i] = _places[i - 1];
                        _places[i - 1] = null;
                    }
                }
            }
            _places[position] = airplane;
            return 1;
        }
        /// <summary>
        /// Удаление объекта из набора с конкретной позиции
        /// </summary>
        /// <param name="position"></param>
        /// <returns></returns>
        public T Remove(int position)
        {
            if (0 > position && position >= Count)
                return null;
            T delobj = _places[position];
            _places[position] = null;
            return delobj;
        }
        /// <summary>
        /// Получение объекта из набора по позиции
        /// </summary>
        /// <param name="position"></param>
        /// <returns></returns>
        public T Get(int position)
        {
            if (position < 0 || position > _places.Length) return null;
            return _places[position];
        }
    }
}
